@@ -4,7 +4,10 @@ use Filter::Util::Call ;
 use Compress::Zlib ;
 use Carp ;
 
-$VERSION = '1.01' ;
+use strict ;
+use warnings ;
+
+my $VERSION = '1.01' ;
 
 sub import
 {
