@@ -3,6 +3,9 @@ package NewSubst ;
 use Filter::Util::Call ;
 use Carp ;
  
+use strict ;
+use warnings ;
+
 sub filter
 {
     my ($self) = @_ ;
